"""
swanki/conf/__init__.py
[[swanki.conf]]
https://github.com/Mjvolk3/Swanki/tree/main/swanki/conf/__init__.py
Test file: tests/test_conf.py

Package default Hydra configuration files for Swanki.
"""
