"""
swanki/__init__.py
[[swanki]]
https://github.com/Mjvolk3/Swanki/tree/main/swanki/__init__.py
Test file: tests/test_swanki.py

Automated flashcard generation from academic PDFs.
"""

from .pipeline import Pipeline as Pipeline

__all__ = [
    "Pipeline",
]
