"""
swanki/pipeline/__init__.py
[[swanki.pipeline.__init__]]
https://github.com/Mjvolk3/Swanki/tree/main/swanki/pipeline/__init__.py

Main processing pipeline for PDF-to-flashcard generation.
"""

from .pipeline import Pipeline

__all__ = ["Pipeline"]
